#!/usr/bin/env node
'use strict';

var _findUp = require('find-up');

var _findUp2 = _interopRequireDefault(_findUp);

var _lodash = require('lodash');

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _safe = require('colors/safe');

var _safe2 = _interopRequireDefault(_safe);

var _index = require('../index');

var _index2 = _interopRequireDefault(_index);

var _binUtils = require('../bin-utils');

var _getLogger = require('../get-logger');

var _getLogger2 = _interopRequireDefault(_getLogger);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var log = (0, _getLogger2.default)();
/* eslint no-process-exit: "off" */

var FAIL_CODE = 1;
var shouldRun = true;

_commander2.default.version(require('../../package.json').version).allowUnknownOption().option('-s, --silent', 'Silent p-s output').option('-p, --parallel <script-name1,script-name2>', 'Scripts to run in parallel (comma seprated)').option('-c, --config <filepath>', 'Config file to use (defaults to nearest package-scripts.js)').option('-l, --log-level <level>', 'The log level to use (error, warn, info [default])').option('-r, --require <module>', 'Module to preload').on('init', onInit).on('--help', onHelp).parse(process.argv);

if (shouldRun) {
  var psConfig = getPSConfig();
  var hasDefaultScript = !!psConfig.scripts.default;
  var scriptsAndArgs = (0, _binUtils.getScriptsAndArgs)(_commander2.default);
  if (!hasDefaultScript && scriptsAndArgs.scripts.length < 1) {
    _commander2.default.outputHelp();
  } else {
    loadAndRun(scriptsAndArgs, psConfig);
  }
}

function loadAndRun(scriptsAndArgs, psConfig) {
  (0, _index2.default)({
    scriptConfig: psConfig.scripts,
    scripts: scriptsAndArgs.scripts,
    args: scriptsAndArgs.args,
    options: (0, _lodash.merge)(psConfig.options, {
      silent: _commander2.default.silent,
      parallel: scriptsAndArgs.parallel,
      logLevel: _commander2.default.logLevel
    })
  }, function (result) {
    if (result.error) {
      log.error(result.error);
      process.exit(FAIL_CODE);
    }
    process.exit(result.code);
  });
}

function getPSConfig() {
  if (_commander2.default.require) {
    (0, _binUtils.preloadModule)(_commander2.default.require);
  }
  var config = (0, _binUtils.loadConfig)(_commander2.default.config || _findUp2.default.sync('package-scripts.js'));
  if (!config) {
    process.exit(FAIL_CODE);
  }
  return config;
}

function onInit() {
  shouldRun = false;

  var _initialize = (0, _binUtils.initialize)();

  var packageScriptsPath = _initialize.packageScriptsPath;

  log.info('Your scripts have been saved at ' + _safe2.default.green(packageScriptsPath));
  log.info(_safe2.default.gray('Check out your scripts in there. Go ahead and update them and add descriptions to the ones that need it'));
  log.info(_safe2.default.gray('Your package.json scripts have also been updated. Run `npm start -- --help` for help'));
}

function onHelp() {
  shouldRun = false;
  log.info((0, _binUtils.help)(getPSConfig()));
}